==> haskell-path-io-1.3.3-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path-io
version: 1.3.3
id: path-io-1.3.3-KnmWfNZWd9l10enDNkjvme
key: path-io-1.3.3-KnmWfNZWd9l10enDNkjvme
license: BSD3
maintainer: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/path-io
synopsis: Interface to ‘directory’ package for users of ‘path’
description:
    Interface to ‘directory’ package for users of ‘path’.
category: System, Filesystem
author: Mark Karpov <markkarpov92@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Path.IO
abi: f7b417c922b2a52cbc98b8b4660f061e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/path-io-1.3.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/path-io-1.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/path-io-1.3.3
hs-libraries: HSpath-io-1.3.3-KnmWfNZWd9l10enDNkjvme
depends:
    base-4.10.1.0 containers-0.5.10.2 directory-1.3.0.2
    dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc
    exceptions-0.8.3-LdkvhAEH3VPBvXQLZp0mCT filepath-1.4.1.2
    path-0.6.1-I9K2RsRnV9HGQG9nNbsgml
    temporary-1.2.1.1-2QgeQJQfCPf69oxJVZZ5cG time-1.8.0.2
    transformers-0.5.2.0 unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc=891025a77d043cfd28f763ce7f5a4b16
             exceptions-0.8.3-LdkvhAEH3VPBvXQLZp0mCT=f624bf973f8eeff6578fe95732b4e11a
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             path-0.6.1-I9K2RsRnV9HGQG9nNbsgml=3ca1ccc1ac7ca478352a70c92637eaf5
             temporary-1.2.1.1-2QgeQJQfCPf69oxJVZZ5cG=ab0f4b4f4a78e7c697cf1bced8c58e9c
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=345a389dfaa60cac4e76e74a938e5e3c
haddock-interfaces: /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html: /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-path-io-1.3.3-17-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path-io
version: 1.3.3
id: path-io-1.3.3-LXw9M8zHpsyEMjx0PBG4GA
key: path-io-1.3.3-LXw9M8zHpsyEMjx0PBG4GA
license: BSD3
maintainer: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/path-io
synopsis: Interface to ‘directory’ package for users of ‘path’
description:
    Interface to ‘directory’ package for users of ‘path’.
category: System, Filesystem
author: Mark Karpov <markkarpov92@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Path.IO
abi: 333fb76a4f6fdbb478e32a3b0ffd2b0f
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/path-io-1.3.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/path-io-1.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/path-io-1.3.3
hs-libraries: HSpath-io-1.3.3-LXw9M8zHpsyEMjx0PBG4GA
depends:
    base-4.10.1.0 containers-0.5.10.2 directory-1.3.0.2
    dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc
    exceptions-0.8.3-LdkvhAEH3VPBvXQLZp0mCT filepath-1.4.1.2
    path-0.6.1-DlMygm2Tp8Iz5JPfzN2IG
    temporary-1.2.1.1-2QgeQJQfCPf69oxJVZZ5cG time-1.8.0.2
    transformers-0.5.2.0 unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc=891025a77d043cfd28f763ce7f5a4b16
             exceptions-0.8.3-LdkvhAEH3VPBvXQLZp0mCT=f624bf973f8eeff6578fe95732b4e11a
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             path-0.6.1-DlMygm2Tp8Iz5JPfzN2IG=6303cbdefb7ec82586521b4262a0688e
             temporary-1.2.1.1-2QgeQJQfCPf69oxJVZZ5cG=ab0f4b4f4a78e7c697cf1bced8c58e9c
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=345a389dfaa60cac4e76e74a938e5e3c
haddock-interfaces: /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html: /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
